@@ -290,8 +290,8 @@ public class ComponentColumn implements Column {
     }
 
     public void resizeLeft() {
-        columnResizeEvent.fire(new ColumnResizeEvent(id,
-                                                     parentElement.getId()).left());
+        columnResizeEvent.fire(new ColumnResizeEvent(hashCode(),
+                                                     parentElement.hashCode()).left());
     }
 
     public boolean canResizeRight() {
@@ -302,8 +302,8 @@ public class ComponentColumn implements Column {
     }
 
     public void resizeRight() {
-        columnResizeEvent.fire(new ColumnResizeEvent(id,
-                                                     parentElement.getId()).right());
+        columnResizeEvent.fire(new ColumnResizeEvent(hashCode(),
+                                                     parentElement.hashCode()).right());
     }
 
     public void recalculateWidth() {
