@@ -72,7 +72,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
 
         final SelectionsTransformer transformer = new DefaultSelectionsTransformer(data,
                                                                                    data.getColumns());
-        final List<SelectedRange> selectedRanges1 = transformer.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges1 = transformer.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(0,
                      selectedRanges1.size());
 
@@ -111,7 +111,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
         assertEquals(5,
                      data.getSelectedCells().size());
 
-        final List<SelectedRange> selectedRanges2 = transformer.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges2 = transformer.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(2,
                      selectedRanges2.size());
     }
@@ -156,7 +156,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
 
         final SelectionsTransformer transformer = new DefaultSelectionsTransformer(data,
                                                                                    data.getColumns());
-        final List<SelectedRange> selectedRanges1 = transformer.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges1 = transformer.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(0,
                      selectedRanges1.size());
 
@@ -195,7 +195,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
         assertEquals(5,
                      data.getSelectedCells().size());
 
-        final List<SelectedRange> selectedRanges2 = transformer.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges2 = transformer.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(3,
                      selectedRanges2.size());
     }
@@ -240,7 +240,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
 
         final SelectionsTransformer transformer1 = new DefaultSelectionsTransformer(data,
                                                                                     data.getColumns());
-        final List<SelectedRange> selectedRanges1 = transformer1.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges1 = transformer1.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(0,
                      selectedRanges1.size());
 
@@ -285,7 +285,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
         }};
         final SelectionsTransformer transformer2 = new FloatingSelectionsTransformer(data,
                                                                                      columns);
-        final List<SelectedRange> selectedRanges2 = transformer2.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges2 = transformer2.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(1,
                      selectedRanges2.size());
     }
@@ -330,7 +330,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
 
         final SelectionsTransformer transformer1 = new DefaultSelectionsTransformer(data,
                                                                                     data.getColumns());
-        final List<SelectedRange> selectedRanges1 = transformer1.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges1 = transformer1.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(0,
                      selectedRanges1.size());
 
@@ -375,7 +375,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
         }};
         final SelectionsTransformer transformer2 = new FloatingSelectionsTransformer(data,
                                                                                      columns);
-        final List<SelectedRange> selectedRanges2 = transformer2.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges2 = transformer2.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(1,
                      selectedRanges2.size());
     }
@@ -420,7 +420,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
 
         final SelectionsTransformer transformer = new DefaultSelectionsTransformer(data,
                                                                                    data.getColumns());
-        final List<SelectedRange> selectedRanges1 = transformer.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges1 = transformer.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(0,
                      selectedRanges1.size());
 
@@ -461,7 +461,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
         assertEquals(6,
                      data.getSelectedCells().size());
 
-        final List<SelectedRange> selectedRanges2 = transformer.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges2 = transformer.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(2,
                      selectedRanges2.size());
     }
@@ -506,7 +506,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
 
         final SelectionsTransformer transformer = new DefaultSelectionsTransformer(data,
                                                                                    data.getColumns());
-        final List<SelectedRange> selectedRanges1 = transformer.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges1 = transformer.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(0,
                      selectedRanges1.size());
 
@@ -545,7 +545,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
         assertEquals(5,
                      data.getSelectedCells().size());
 
-        final List<SelectedRange> selectedRanges2 = transformer.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges2 = transformer.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(3,
                      selectedRanges2.size());
     }
@@ -590,7 +590,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
 
         final SelectionsTransformer transformer = new DefaultSelectionsTransformer(data,
                                                                                    data.getColumns());
-        final List<SelectedRange> selectedRanges1 = transformer.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges1 = transformer.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(0,
                      selectedRanges1.size());
 
@@ -629,7 +629,7 @@ public class GridCellSelectionsTransformationTest extends BaseGridTest {
         assertEquals(5,
                      data.getSelectedCells().size());
 
-        final List<SelectedRange> selectedRanges2 = transformer.transformToSelectedRanges();
+        final List<SelectedRange> selectedRanges2 = transformer.transformToSelectedRanges(data.getSelectedCells());
         assertEquals(5,
                      selectedRanges2.size());
     }
